@@ -136,7 +136,9 @@ def cluster(FI, df_search, V, path, opt):
 
     # If no evidence available, return it
     if df_search is None:
-        logging.warning(f"No adjusted_group assigned to {FI}")
+        # if confident is True, no adjusted_group for db is normal situation
+        if opt.confident is False and FI.datatype is "db":
+            logging.warning(f"No adjusted_group assigned to {FI}")
         FI.adjusted_group = FI.group
         return FI, None
     # for db sequence with group, retain it
@@ -217,17 +219,25 @@ def append_outgroup(V, df_search, gene, group, path, opt):
         funinfo_dict[funinfo.hash] = funinfo
 
     # For non-concatenated analysis
-    """
-    if gene != "concatenated":
+
+    # if gene != "concatenated":
+    if 1:
         # generate minimal bitscore cutoff that does not overlaps to query-query bitscore value range
+
+        ## For getting inner group
         cutoff_set_df = df_search[df_search["subject_group"] == group]
         try:
-            bitscore_cutoff = min(cutoff_set_df["bitscore"])
+            # offset will prevent selecting outgroup too close to ingroup
+            bitscore_cutoff = max(
+                1, min(cutoff_set_df["bitscore"]) - opt.outgroupoffset
+            )
         except:
             bitscore_cutoff = 999999  # use infinite if failed
 
-        # get result stasifies over cutoff
+        ## get result stasifies over cutoff
+        # outgroup should be outside of ingroup
         cutoff_df = df_search[df_search["bitscore"] < bitscore_cutoff]
+        # Remove malformat result
         cutoff_df = cutoff_df[cutoff_df["bitscore"] > 0]
 
         # split that same group to include all to alignment, and left other groups for outgroup selection
@@ -255,9 +265,9 @@ def append_outgroup(V, df_search, gene, group, path, opt):
     else:
         cutoff_df = df_search[df_search["bitscore"] > 0]
         cutoff_df = cutoff_df[cutoff_df["subject_group"] != group]
-    """
-    cutoff_df = df_search[df_search["bitscore"] > 0]
-    cutoff_df = cutoff_df[cutoff_df["subject_group"] != group]
+
+    # cutoff_df = df_search[df_search["bitscore"] > 0]
+    # cutoff_df = cutoff_df[cutoff_df["subject_group"] != group]
 
     del df_search
     gc.collect()
@@ -417,8 +427,13 @@ def group_cluster_opt_generator(V, opt, path):
 
 # opts ready for multithreading in outgroup append
 def outgroup_append_opt_generator(V, path, opt):
+    from time import time
+
+    time1 = time()
+
     opt_append_outgroup = []
 
+    #### Pararellize this part
     # if concatenated analysis is false
     # Assign different outgroup for each dataset
     for group in V.dict_dataset:
@@ -452,6 +467,10 @@ def outgroup_append_opt_generator(V, path, opt):
                     f"{group} / concatenated dataset exists, but cannot append outgroup due to no corresponding search result"
                 )
 
+    time2 = time()
+
+    logging.info(f"{time2-time1}s consumed in outgroup_append_opt_generator")
+
     return opt_append_outgroup
 
 
